![PyPI - License](https://img.shields.io/pypi/l/pydaikin?color=green)
![Bitbucket open pull requests](https://img.shields.io/bitbucket/pr/mustang51/pydaikin?logo=bitbucket&logoColor=white)
![PyPI - Downloads](https://img.shields.io/pypi/dw/pydaikin?label=downloads&logo=pypi&logoColor=white)
![PyPI - Version](https://img.shields.io/pypi/v/pydaikin?label=version&logo=pypi&logoColor=white)

PyDaikin is a standalone program and a library that interface AirConditioners from Daikin.

Currently the following Daikin WiFi modules are supported:

* BRP069Axx/BRP069Bxx/BRP072Axx
* BRP15B61 aka. AirBase (similar protocol as BRP069Axx)

Version 2.0 will add support for the following models:

* BRP072B/Cxx (needs https access and a key)
* SKYFi (different protocol, have a password)

The integration was initially built by Yari Adan, but lately have been taken over by Fredrik Erlandsson.
